@@ -49,7 +49,11 @@
 #include "usb.h"
 #endif
 
-#include <dev/usb/usb.h>
+#ifdef __DragonFly__
+# include <bus/u4b/usb.h>
+#else
+# include <dev/usb/usb.h>
+#endif
 #ifdef USB_GET_REPORT_ID
 #define USB_NEW_HID
 #endif
@@ -546,10 +550,8 @@ usbMouseProc(DeviceIntPtr pPointer, int what)
                 pInfo->fd = -1;
             } else {
                 xf86FlushInput(pInfo->fd);
-#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) < 23
                 if (!xf86InstallSIGIOHandler (pInfo->fd, usbSigioReadInput,
                                               pInfo))
-#endif
                     AddEnabledDevice(pInfo->fd);
             }
         }
